package com.bonus.canteen.core.cook.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.cook.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.cook.domain.CookCollectionDishes;
import com.bonus.canteen.core.cook.service.ICookCollectionDishesService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 菜品收藏Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "菜品收藏接口")
@RestController
@RequestMapping("/cook_collection_dishes")
public class CookCollectionDishesController extends BaseController {
    @Autowired
    private ICookCollectionDishesService cookCollectionDishesService;

    /**
     * 查询菜品收藏列表
     */
    @ApiOperation(value = "查询菜品收藏列表")
    //@RequiresPermissions("cook:dishes:list")
    @GetMapping("/list")
    public TableDataInfo list(CookCollectionDishes cookCollectionDishes) {
        startPage();
        List<CookCollectionDishes> list = cookCollectionDishesService.selectCookCollectionDishesList(cookCollectionDishes);
        return getDataTable(list);
    }

    /**
     * 导出菜品收藏列表
     */
    @ApiOperation(value = "导出菜品收藏列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:dishes:export")
    @SysLog(title = "菜品收藏", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品收藏")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CookCollectionDishes cookCollectionDishes) {
        List<CookCollectionDishes> list = cookCollectionDishesService.selectCookCollectionDishesList(cookCollectionDishes);
        ExcelUtil<CookCollectionDishes> util = new ExcelUtil<CookCollectionDishes>(CookCollectionDishes.class);
        util.exportExcel(response, list, "菜品收藏数据");
    }

    /**
     * 获取菜品收藏详细信息
     */
    @ApiOperation(value = "获取菜品收藏详细信息")
    //@RequiresPermissions("cook:dishes:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(cookCollectionDishesService.selectCookCollectionDishesById(id));
    }

    /**
     * 新增菜品收藏
     */
    @ApiOperation(value = "新增菜品收藏")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:dishes:add")
    @SysLog(title = "菜品收藏", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品收藏")
    @PostMapping
    public AjaxResult add(@RequestBody CookCollectionDishes cookCollectionDishes) {
        try {
            return toAjax(cookCollectionDishesService.insertCookCollectionDishes(cookCollectionDishes));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改菜品收藏
     */
    @ApiOperation(value = "修改菜品收藏")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:dishes:edit")
    @SysLog(title = "菜品收藏", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品收藏")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CookCollectionDishes cookCollectionDishes) {
        try {
            return toAjax(cookCollectionDishesService.updateCookCollectionDishes(cookCollectionDishes));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除菜品收藏
     */
    @ApiOperation(value = "删除菜品收藏")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:dishes:remove")
    @SysLog(title = "菜品收藏", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品收藏")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(cookCollectionDishesService.deleteCookCollectionDishesByIds(ids));
    }
}
